Changes
=======

2.0.0 -- 2020-08-dd
-------------------
* Renamed segno-pil to qrcode-artistic
* Fixed `#1 <https://github.com/heuer/segno-pil/issues/1>`_:
  Support for background images and animated QR codes.

1.0.0 -- 2020-08-07
-------------------
* Support for multiple module colors
* Support for Segno's API >= 1.0.0
* API breaking changes:

  - Changed parameter "color" to "dark" and "background" to "light"
    to match Segno's API
  - Removed "mode" parameter


0.1.6 -- 2016-09-19
-------------------
* Fixed Python packaging


0.1.5 -- 2016-08-24
-------------------
* Adapt Segno's 0.1.6 API changes.


0.1.4 -- 2016-08-16
-------------------
* Updated docs


0.1.3 -- 2016-08-14
-------------------
* Initial release
